this is the list page

{% if content %}
<ul>
    {% for course in content %}
    <li><a href="/courses/{{ course.course_id }}/">{{ course.course_name }}</a></li>
    {% endfor %}
</ul>
{% else %}
<p>No polls are available.</p>
{% endif %}